#
# spec file for package cracklib
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cracklib
BuildRequires:  automake
BuildRequires:  gzip
BuildRequires:  libtool
BuildRequires:  translation-update-upstream
BuildRequires:  zlib-devel
Url:            http://sourceforge.net/projects/cracklib
# bug437293
%ifarch ppc64
Obsoletes:      cracklib-64bit
%endif
#
Version:        2.9.0
Release:        0
Requires:       cracklib-dict
Summary:        Library to crack passwords using dictionaries
License:        LGPL-2.1
Group:          System/Libraries
Source:         http://prdownloads.sourceforge.net/cracklib/cracklib-%{version}.tar.gz
Source2:        baselibs.conf
# PATCH-FIX-OPENSUSE (should be upstreamed)
# Remove support for broken 64bit indexes from magic entry [bnc#106007]
Patch:          cracklib-magic.diff
# PATCH-FIX-OPENSUSE Hide non-public functions
Patch1:         cracklib-visibility.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
CrackLib tests passwords to determine whether they match
certainsecurity-oriented characteristics. You can use CrackLib to
stopusers from choosing passwords that are too simple.This package
contains a full dictionary file used by cracklib.



%package devel
Summary:        Header files and libraries for developing apps which will use CrackLib
Group:          Development/Libraries/C and C++
Provides:       cracklib:/usr/include/crack.h
Requires:       glibc-devel
Requires:       libcrack2 = %{version}

%description devel
The cracklib-devel package contains the header files and libraries
needed to develop programs that use the CrackLib functions to to
determine whether passwords match certain security-oriented
characteristics.


%package -n libcrack2
Summary:        Library to crack passwords using dictionaries
Group:          System/Libraries
Requires:       cracklib >= %{version}

%description -n libcrack2
CrackLib tests passwords to determine whether they match
certainsecurity-oriented characteristics. You can use CrackLib to
stopusers from choosing passwords that are too simple.This package
contains a full dictionary file used by cracklib.

%package dict-small
Summary:        Small dictionary for cracklib - A Password-Checking Library
Group:          System/Libraries
Provides:       cracklib-dict
Conflicts:      cracklib-dict-full

%description dict-small
CrackLib tests passwords to determine whether they match certain
security-oriented characteristics. You can use CrackLib to stop users
from choosing passwords that are easy to guess.

This package contains a small dictionay file used by cracklib.



%prep
%setup -q
translation-update-upstream
%patch
%patch1

%build
AUTOPOINT=true autoreconf -fi
%configure --enable-hidden-symbols --disable-static --with-pic
%{__make} %{?_smp_mflags}
#make -C po update-po

%install
mkdir -p $RPM_BUILD_ROOT/usr/lib
make install DESTDIR=$RPM_BUILD_ROOT
# libtool is broken by design, remove this *.la files ...
rm $RPM_BUILD_ROOT/%{_libdir}/libcrack.la
# set executable
chmod 755 ./util/cracklib-format
# Adjust path in comment
sed "s,/usr/lib/cracklib_dict,%{_datadir}/cracklib/pw_dict,g" lib/crack.h > $RPM_BUILD_ROOT/%{_includedir}/crack.h
./util/cracklib-format ./dicts/cracklib-small | \
./util/cracklib-packer $RPM_BUILD_ROOT/%{_datadir}/cracklib/pw_dict
ln -s cracklib-format $RPM_BUILD_ROOT/%{_sbindir}/mkdict
ln -s cracklib-packer $RPM_BUILD_ROOT/%{_sbindir}/packer
rm -f $RPM_BUILD_ROOT/%{_datadir}/cracklib/cracklib-small
ln -sf %{_datadir}/cracklib/pw_dict.hwm $RPM_BUILD_ROOT/usr/lib/cracklib_dict.hwm
ln -sf %{_datadir}/cracklib/pw_dict.pwd $RPM_BUILD_ROOT/usr/lib/cracklib_dict.pwd
ln -sf %{_datadir}/cracklib/pw_dict.pwi $RPM_BUILD_ROOT/usr/lib/cracklib_dict.pwi
#
# using zip'ed dict takes too long for a check. But the support
# for this is still in the lib. 
#
#gzip $RPM_BUILD_ROOT/%{_datadir}/cracklib/pw_dict.pwd
#ln -sf %{_datadir}/cracklib/pw_dict.pwd.gz $RPM_BUILD_ROOT/usr/lib/cracklib_dict.pwd.gz
%{find_lang} %{name}
%ifnarch ppc64
nm -C -D %{buildroot}%{_libdir}/libcrack.so.2 | grep ' T '
%endif

%check
make check

%post -n libcrack2 -p /sbin/ldconfig

%postun -n libcrack2 -p /sbin/ldconfig

%files -n libcrack2
%defattr(-,root,root)
%{_libdir}/libcrack.so.2
%{_libdir}/libcrack.so.2.*

%files -f %{name}.lang
%defattr(-,root,root)
%doc README README-WORDS NEWS README-LICENSE README-DAWG AUTHORS COPYING.LIB
/usr/sbin/create-cracklib-dict
/usr/sbin/mkdict
/usr/sbin/packer
/usr/sbin/cracklib-check
/usr/sbin/cracklib-format
/usr/sbin/cracklib-packer
/usr/sbin/cracklib-unpacker
%dir %{_datadir}/cracklib
%{_datadir}/cracklib/cracklib.magic
/usr/lib/cracklib_dict.hwm
/usr/lib/cracklib_dict.pwd
/usr/lib/cracklib_dict.pwi

%files devel
%defattr(644,root,root,755)
%{_includedir}/crack.h
%{_includedir}/packer.h
%{_libdir}/libcrack.so

%files dict-small
%defattr(-,root,root)
%{_datadir}/cracklib/pw_dict.hwm
%{_datadir}/cracklib/pw_dict.pwd
%{_datadir}/cracklib/pw_dict.pwi

%changelog
